pm4py.algo.merging.case\_relations package
==========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.merging.case_relations.variants

Submodules
----------

pm4py.algo.merging.case\_relations.algorithm module
---------------------------------------------------

.. automodule:: pm4py.algo.merging.case_relations.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.merging.case_relations
   :members:
   :undoc-members:
   :show-inheritance:
